``dageo`` - Data Assimilation in Geosciences
============================================

Data Assimilation in Geosciences is, for now, a simple 2D reservoir simulator
and a straight-forward implementation of the basic *Ensemble smoother with
multiple data assimilation* (ESMDA) algorithm as presented by Emerick and
Reynolds, 2013. However, more DA methods and examples might be added in the
future.

- **Documentation:** https://tuda-geo.github.io/dageo
- **Source Code:** https://github.com/tuda-geo/dageo
- **Bug reports:** https://github.com/tuda-geo/dageo/issues


Available through pip and conda:
``pip install dageo`` / ``conda install -c conda-forge dageo``.


(Note that until v1.0.2, ``dageo`` was called ``resmda``.)
